@@ -10,7 +10,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
 
 from openstack_dashboard.test import helpers as test
 from openstack_dashboard.test.test_data import utils
